@@ -127,8 +127,9 @@ laGP <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
 
 ## laGP.R:
 ##
-## and R-loop version of the laGP function (which will use
-## C when written)
+## and R-loop version of the laGP function; the main reason this is 
+## much slower than the C-version (laGP) is that it must pass/copy
+## a big X-matrix each time it is called
 
 laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
                    method=c("alc", "alcray", "mspe", "nn", "efi"), 
@@ -139,6 +140,7 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
   {
     ## argument matching
     method <- match.arg(method)
+    parallel <- match.arg(parallel)
 
     ## massage Xref
     if(!is.matrix(Xref)) Xref <- matrix(Xref, ncol=ncol(X))
@@ -159,10 +161,12 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
         stop("numrays should be an integer scalar >= 1")
     } else if(!is.null(rect)) warning("rect only used by alcray method")
 
-    ## process the d argument
+    ## process the d and g arguments
     d <- darg(d, X)
-    ## process the g argument
     g <- garg(g, Z)
+    ## sanity check
+    if(length(d$start) != 1 || length(g$start) != 1)
+      stop("laGP starting values should be scalars")
 
     ## check Xi.ret argument
     if(!( is.logical(Xi.ret) && length(Xi.ret) == 1))
@@ -173,13 +177,17 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
     ## for timing
     tic <- proc.time()[3]
 
-    ## sorting to Xref location, and building new GP
+    ## sorting to Xref location
     dst <- drop(distance(Xref, X))
     if(is.matrix(dst)) dst <- apply(dst, 2, min)
     cands <- order(dst)
     Xi <- cands[1:start]
+
+    ## building a new GP with closest Xs to Xref
     gpi <- newGP(X[Xi,,drop=FALSE], Z[Xi], d=d$start, g=g$start, 
-                 dK=(method != "alc" || d$mle))
+                 dK=(method != "alc" && method != "alcray"))
+
+    ## for the output object
     if(!is.null(Xi.ret)) Xi.ret[1:start] <- Xi
 
     ## if pall, then predict after every iteration
@@ -207,10 +215,14 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
       ## calc ALC to reference
       if(method == "alcray") {
         offset <- ((t-start) %% floor(sqrt(t-start))) + 1
-        w <- lalcrayGP(gpi, Xref, X[cands,,drop=FALSE], rect, offset, numrays, verb=verb-2)
+        w <- lalcrayGP(gpi, Xref, X[cands,,drop=FALSE], rect, offset, numrays, 
+              verb=verb-2)
       } else {
-        if(method == "alc") als <- alcGP(gpi, X[cands,,drop=FALSE], Xref, parallel=parallel, verb=verb-2)
-        else if(method == "mspe") als <- 0.0 - mspeGP(gpi, X[cands,,drop=FALSE], Xref, verb=verb-2)
+        if(method == "alc") 
+          als <- alcGP(gpi, X[cands,,drop=FALSE], Xref, parallel=parallel, 
+                       verb=verb-2)
+        else if(method == "mspe") 
+          als <- 0.0 - mspeGP(gpi, X[cands,,drop=FALSE], Xref, verb=verb-2)
         else if(method == "efi") als <- efiGP(gpi, X[cands,,drop=FALSE])
         else als <- c(1, rep(0, length(cands)-1)) ## nearest neighbor
         als[!is.finite(als)] <- NA
@@ -224,7 +236,7 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
     }
 
     ## maybe do post-MLE calculation 
-    mle <- mleGP.switch(gpi, d, g, verb)
+    mle <- mleGP.switch(gpi, method, d, g, verb)
 
     ## Obtain final prediction
     outp <- predGP(gpi, Xref, lite=(nrow(Xref)==1))
@@ -257,7 +269,9 @@ laGP.R <- function(Xref, start, end, X, Z, d=NULL, g=1/1000,
 ## aGP.R:
 ##
 ## loops over all predictive locations XX and obtains adaptive approx
-## kriging equations for each based on localized subsets of (X,Z)
+## kriging equations for each based on localized subsets of (X,Z); 
+## the main reason this is much slower than the C-version (aGPsep) is 
+## that it must pass/copy a big X-matrix each time it is called
 
 aGP.R <- function(X, Z, XX, start=6, end=50, d=NULL, g=1/1000,
                   method=c("alc", "alcray", "mspe", "nn", "efi"), Xi.ret=TRUE, 
@@ -320,8 +334,9 @@ aGP.R <- function(X, Z, XX, start=6, end=50, d=NULL, g=1/1000,
       ## local calculation, (add/remove .R in laGP.R for R/C version)
       di <- list(start=d$start[i], mle=d$mle, min=d$min, max=d$max, ab=d$ab)
       gi <- list(start=g$start[i], mle=g$mle, min=g$min, max=g$max, ab=g$ab)
-      outp <- laGP(XX[i,,drop=FALSE], start, end, X, Z, d=di, g=gi, method=method,
-                   Xi.ret=Xi.ret, close=close, numrays=numrays, rect=rect, verb=verb-1)
+      outp <- laGP(XX[i,,drop=FALSE], start, end, X, Z, d=di, g=gi, 
+                method=method, Xi.ret=Xi.ret, close=close, numrays=numrays,
+                rect=rect, verb=verb-1)
 
       ## save MLE outputs and update gpi to use new dmle
       if(!is.null(dmle)) { dmle[i] <- outp$mle$d; dits[i] <- outp$mle$dits }
